Development Lead:
-----------------

1. 	William Stephenson <willste@umich.edu>

Credits:
--------

1. Xiaoming Mao <maox@umich.edu>
2. Nicholas Kotov <kotov@umich.edu>
3. Dickson Owuor <owuordickson@gmail.com>


Contributors:
-------------
Feel free to add yourself:
